<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d კავშირი';
$lang['%d associations'] = '%d კავშირი';
$lang['%d album including'] = '%d კატეგორია დამატებულია ';
$lang['%d albums including'] = 'დამატებული კატეგორიები: %d';
$lang['%d physical'] = '%d რეალური';
$lang['%d physical'] = '%d რეალური';
$lang[' and %d virtual'] = ' და %d ვირტუალური';
$lang[' and %d virtual'] = ' და %d ვირტუალური';
$lang['%d album moved'] = '%d კატეგორია გადატანილია';
$lang['%d albums moved'] = '%d კატეგორია გადატანილია';
$lang['%d group'] = '%d ჯგუფი';
$lang['%d groups'] = '%d ჯგუფი';
$lang['%d member'] = '%d მონაწილე';
$lang['%d members'] = '%d მონაწილე';
$lang['%d tag'] = '%d სიტყვა';
$lang['%d tags'] = '%d სიტყვები';
$lang['%d user comment rejected'] = '%d მომხმარებლის კომენტარი აცილებულია';
$lang['%d user comments rejected'] = '%d მომხმარებლის კომენტარები აცილებულია';
$lang['%d user comment validated'] = '%d მომხმარებლის კომენტარი მიღებულია';
$lang['%d user comments validated'] = '%d მომხმარებლის კომენტარები მიღებული';
$lang['%d user deleted'] = '%d მომხმარებელი წაშლილია';
$lang['%d users deleted'] = '%d მომხმარებელი წაშლილია';
$lang['%d user'] = '%d მომხმარებელი';
$lang['%d users'] = '%d მომხმარებელი';
$lang['%d waiting for validation'] = '%d უცდის შემოწმებას';
$lang['Actions'] = 'მოქმედება';
$lang['Activate'] = 'აქტივაცია';
$lang['Add/delete a permalink'] = 'დავამატოთ/წავშალოთ მუდმივი ბმული';
$lang['Add a tag'] = 'დავამატოთ სიტყვა';
$lang['Add a user'] = 'დავამატოთ მომხმარებელი';
$lang['Add group'] = 'დავამატოთ ჯგუფი';
$lang['Add'] = 'დავამატოთ';
$lang['Allow user registration'] = 'დაუშვათ მომხმარებლების რეგისტრაცია';
$lang['Apply to sub-albums'] = 'გამოვიყენოთ ქვეკატეგორიებისთვისაც';
$lang['Associated'] = 'დაკავშირებული';
$lang['Batch management'] = 'პაკეტური დამუშავება';
$lang['Caddie management'] = 'კალათის მართვა';
$lang['Caddie'] = 'კალათა';
$lang['Albums authorized thanks to group associations'] = 'კატეგორიები, რომლებიც დაშვებულია ჯგუფთან კავშირის გამო';
$lang['Album manual order was saved'] = 'კატეგორიების განსაკუთრებული წყობა შენახულია';
$lang['Check for upgrade failed for unknown reasons.'] = 'განახლების შემოწმება უცნობი მიზეზების გამო არ შესრულდა.';
$lang['Check for upgrade'] = 'განახლების შემოწმება';
$lang['Comments for all'] = 'კომენტარები ყველასათვის';
$lang['Current name'] = 'მიმდინარე სახელი';
$lang['Database'] = 'მონაცემთა ბაზა';
$lang['Deactivate'] = 'გამორთვა';
$lang['Delete Representant'] = 'წარმომადგენლის წაშლა';
$lang['Delete selected tags'] = 'არჩეული სიტყვების წაშლა';
$lang['Delete selected users'] = 'არჩეული მომხმარებლების წაშლა';
$lang['Deletions'] = 'წაშლები';
$lang['Deny selected groups'] = 'უარი ჯგუფის არჩევაზე';
$lang['Deny selected users'] = 'უარი მომხმარებილს არჩევაზე';
$lang['Description'] = 'აღწერა';
$lang['Display options'] = 'ნახვის ვარიანტები';
$lang['Dissociated'] = 'დაუკავშირებლები';
$lang['Does not represent'] = 'წარმომადგენელი არ არის';
$lang['Edit selected tags'] = 'გამოყოფილი სიტყვების რედაქტირება';
$lang['Edit tags'] = 'სიტყვების რედაქტირება';
$lang['Email admins when a new user registers'] = 'შევატყობინოთ ადმინისტრატორს ახალი მომხმარებლის რეგისტრაცია';
$lang['Email admins when a valid comment is entered'] = 'შევატყობინოთ ადმინისტრატორს ახალი კომენტარის შესახებ';
$lang['Email admins when a comment requires validation'] = 'შევატყობინოთ ადმინისტრატორს შესამოწმებელი კომანტარის შესახებ';
$lang['Environment'] = 'გარემოცვა';
$lang['Form'] = 'მოქმედებები';
$lang['Gallery title'] = 'გალერეის სახელი';
$lang['Grant selected groups'] = 'ნება დავრთოთ რჩეულ ჯგუფებს';
$lang['Grant selected users'] = 'ნება დავრთოთ რჩეულ მომხმარებლებს';
$lang['Group name'] = 'ჯგუფის სახელი';
$lang['Groups'] = 'ლგუფები';
$lang['Guests'] = 'სტუმრები';
$lang['History'] = 'ისტორია';
$lang['Informations'] = 'ინფორმაცია';
$lang['Install'] = 'დავაყენოთ';
$lang['Link all album photos to a new album'] = 'დაუკავშიროთ ამ კატეგორიის ყველა ელემენტი ახალს';
$lang['Link all album photos to some existing albums'] = 'დაუკავშიროთ ამ კატეგორიის ყველა ელემენტი ერთ ერთ არსებულს';
$lang['Linked albums'] = 'დაკავშირებული კატეგორიები';
$lang['Lock gallery'] = 'დავბლოკოთ გალერეა';
$lang['Maintenance'] = 'მომსახურება';
$lang['Edit album permissions'] = 'ნებართვების მართვა კატეგორიებისათვის';
$lang['Manage permissions for group "%s"'] = 'ნებართვების მართვა ჯგუფისთვის  "%s"';
$lang['Manage permissions for user "%s"'] = 'ნებართვების მართვა მომხმარებლებისათვის  "%s"';
$lang['Manage tags'] = 'სიტყვების მართვა';
$lang['Members'] = 'მონაწილეები';
$lang['Metadata synchronized from file'] = 'მეტამონაცემები სინქრონიზირებულია ფაილთან';
$lang['Move albums'] = 'კატეგორიის გადატანა';
$lang['Move'] = 'გადატანა';
$lang['Name'] = 'სახელი';
$lang['New name'] = 'ახალი სახელი';
$lang['New parent album'] = 'ახალი მშობლიური კატეგორია';
$lang['New tag'] = 'ახალი სიტყვა';
$lang['Number of comments per page'] = 'კომენტარების რაოდენობა გვერდზე';
$lang['Number of rates'] = 'შეფასების რაოდენობა';
$lang['Number of thumbnails to create'] = 'შესაქმნელი ინიატურების რაოდენობა';
$lang['Only private albums are listed'] = 'მხოლოდ დაფარული კატეგორიების ჩვენება';
$lang['Operating system'] = 'ოპერატიული სისტემა';
$lang['Options'] = 'ოპციები';
$lang['Other private albums'] = 'პრივატულ კატეგორიებთან დაშვება';
$lang['Page banner'] = 'წარწერა ბანერზე';
$lang['Parent album'] = 'მშობლიური კატეგორია';
$lang['Path'] = 'გზა';
$lang['Permalink'] = 'მუდმივი მისამართი';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'მუდმივი მისამართი %s ადრე გამოიყენებოდა კატეგორიისთვის %s. წაშალეთ იგი მანამდე მუდმივი მისამართების ისტორიიდან';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'მუდმივი მისამართი უნდა შედგებოდეს  a-z, A-Z, 0-9, "-" ან"_". იგი არ უნდა იყოს რიცხობრივი და არ უნდა იწყებოდეს რიცხვით "-"';
$lang['Permalink %s is already used by album %s'] = 'მუდმივი მისამართი %s უკვე გამოიყენება კატეგორიისათვის %s';
$lang['Permalink history'] = 'მუდმივი მისამართების სია';
$lang['Permalinks'] = 'მუდმივი მისამართი';
$lang['Permission denied'] = 'დაშვება აკრძალულია';
$lang['Permission granted thanks to a group'] = 'ჯგუფისთვის დაშვება შესაძლებელია';
$lang['Permission granted'] = 'დაშვება შესაძლებელია';
$lang['Photo informations updated'] = 'ინფორმაცია ფოტოსთვის განახლებულია';
$lang['Plugins'] = 'პლაგინები';
$lang['Position'] = 'ნომერი';
$lang['Preferences'] = 'გასწორება';
$lang['Properties'] = 'თვისებები';
$lang['Random photo'] = 'შემთხვევითი ფოტო';
$lang['Rate date'] = 'თარიღი';
$lang['Rating by guests'] = 'სტუმრების შეფასება';
$lang['Rating'] = 'შეფასება';
$lang['Reject'] = 'უარი';
$lang['Representant'] = 'წარმომადგენელი';
$lang['Representation of albums'] = 'წარმოდგენილი კატეგორიები';
$lang['Representative'] = 'წარმომადგენელი';
$lang['Represents'] = 'წარმოადგენს';
$lang['Save order'] = 'შევინახოთ წყობა';
$lang['Save to permalink history'] = 'შევინახოთ მუდმვი მისამართების ისტორია';
$lang['Select at least one album'] = 'აირჩიეთ ერთი კატეგორია მაინც';
$lang['Select at least one photo'] = 'აირჩიეთ ერთი ფოტო მაინც';
$lang['Select at least one user'] = 'აირჩიეთ ერთი მომხმარებელი მაინც';
$lang['Show info'] = 'ვნახოთ ინფორმაცია';
$lang['Site manager'] = 'საიტების მართვა';
$lang['Status'] = 'სტატუსი';
$lang['Statistics'] = 'სტატისტიკა';
$lang['Storage album'] = 'შენახვის კატეგორია';
$lang['Sum of rates'] = 'მთლიანი შეფასება';
$lang['Tag "%s" already exists'] = 'სიტყვა "%s" უკვე არის';
$lang['Tag "%s" was added'] = 'სიტყვა "%s" დამატებულია';
$lang['Tag selection'] = 'სიტყვების არჩევა';
$lang['The %d following tags were deleted'] = '%d მითითებული სიტყვა წაშლილია';
$lang['Uninstall'] = 'დეინსტალაცია';
$lang['Use the default photo sort order (defined in the configuration file)']='სურათების სორტირება ძირითადად (როგორც კონფიგურაციის ფაილშია)';
$lang['User comments validation'] = 'მომხმარებლების კომენტარების შემოწმება';
$lang['Users'] = 'მომხმარებლები';
$lang['Validate'] = 'მივიღოთ';
$lang['Validation'] = 'შემოწმება';
$lang['Version'] = 'ვერსია';
$lang['Virtual albums to move'] = 'ვირტუალური კატეგორიები გადასატანად';
$lang['Virtual album name'] = 'ვირტუალური კატეგორიების სახელები';
$lang['Webmaster cannot be deleted'] = 'ვებმასტერის წაშლა არ შეიძლება';
$lang['You are running on development sources, no check possible.'] = 'მუშაობს დამუშავების პროცესში, შემოწმწბა შეუძლებელია.';
$lang['You cannot delete your account'] = "თქვენ არ შეგიძლიათ თქვენი აკკაუნთის წაშლა";
$lang['You cannot move an album in its own sub album'] = 'თქვენ არ შეგიძლიათ გადააადგილოთ კატეგორია მის ქვეკატერორიაში';
$lang['You need to confirm deletion'] = 'თქვენ უნდა დაადასტუროთ წაშლა';
$lang['add tags'] = 'დავამატოთ სიტყვები';
$lang['Associate to album'] = 'მივამაგროთ კატეგორიას';
$lang['associate to group'] = 'მივამაგროთ ჯგუფს';
$lang['Authorized'] = 'დასაშვებია';
$lang['Add a virtual album'] = 'დავამატოთ ვირტუალური კატეგორია';
$lang['Authorize users to add comments on selected albums'] = 'ნება დავრთოთ მომხმარებლებს დაამატონ კომენტარები არჩეულ კატეგორიებს';
$lang['The name of an album must not be empty'] = 'კატეგორიის სახელი ცარიელი არ უნდა იყოს';
$lang['Lock albums'] = 'დავბლოკოთ კატეგორიები';
$lang['Private'] = 'პირადი(პრივატული) კატეგორია';
$lang['Public'] = 'საერთო კატეგორია';
$lang['Find a new representant by random'] = 'ვიპოვოტ ახალი წარმომადგენელი შემთხვევითი მეთოდით';
$lang['Public / Private'] = 'საერთო / პრივატული';
$lang['Manage authorizations for selected albums'] = 'ავტორიზაციის მართვა არჩეული კატეგორიებისათვის';
$lang['Virtual album added'] = 'ვირტუალური კატეგორია დამატებულია';
$lang['Virtual album deleted'] = 'ვირტუალური კატეგორია წაშლილია';
$lang['Access type'] = 'დაშვების ტიპი';
$lang['Comments'] = 'კომენტარები';
$lang['Information data registered in database'] = 'ინფორმაცია დარეგისტრირებულია მონაცემთა ბაზაში';
$lang['Default display'] = 'ძირითადი სახე';
$lang['The gallery URL is not valid.'] = 'არაკორექტული URL გალერეისათვის';
$lang['Main'] = 'მთავარი';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'გვერდზე შეიძლება იყოს 5 დან 50 კომენტარამდე.';
$lang['Configuration'] = 'გასწორება';
$lang['confirm'] = 'დასტური';
$lang['delete album'] = 'წავშალოთ კატეგორია';
$lang['Dissociate from album'] = 'მოვაშოროთ კატეგორიას';
$lang['dissociate from group'] = 'მოვაშოროთ ჯგუფს';
$lang['edit album permissions'] = 'კატეგორიის უფლებების რედაქტირება';
$lang['Album updated successfully'] = 'ინფორმაცია კატეგორიაზე წარმატებით განახლებულია.';
$lang['photos per page'] = 'მინიატურები გვერდზე';
$lang['High definition enabled'] = 'არსებობს დიდი გაფართოებით';
$lang['File'] = 'ფაილი';
$lang['Filesize'] = 'ფაილის ზომა';
$lang['first photo added on %s'] = 'პირველი ელემენტი დამატებულია %s';
$lang['Forbidden'] = 'აკრძალულია';
$lang['global mode'] = 'ჯგუფური რეჟიმი';
$lang['group "%s" added'] = 'ჯგუფი "%s" დამატებულია';
$lang['group "%s" deleted'] = 'ჯგუფი "%s" წაშლილია';
$lang['group "%s" updated'] = 'ჯგუფი "%s" განახლებულია';
$lang['group'] = 'ჯგუფი';
$lang['The name of a group must not contain " or \' or be empty.'] = 'ჯგუფის სახელი არ უნდა შეიცავდეს  " ან \' და არ უნდა იყოს ცარიელი.';
$lang['This name is already used by another group.'] = 'ეს სახელი უკვე გამოყენებულია სხვა ჯგუფის მიერ.';
$lang['Groups'] = 'ჯგუფები';
$lang['High definition'] = 'დიდი გაფართოება';
$lang['jump to album'] = 'კატეგორიაში გადასვლა';
$lang['jump to photo'] = 'ფოტოებში გადასვლა';
$lang['leave'] = 'დავტოვოთ';
$lang['Lock'] = 'ბლოკირება';
$lang['Locked'] = 'დაბლოკილია';
$lang['manage album photos'] = 'კატეგორიის ფოტოების მართვა';
$lang['manage sub-albums'] = 'ქვეკატეგორიების მართვა';
$lang['Manage'] = 'მართვა';
$lang['maximum height'] = 'მაქსიმალური სიმაღლე';
$lang['maximum width'] = 'მაქსიმალური სიგანე';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'შესრულების დრო ამოიწურა, დამუშავება უნდა გაგრძელდეს [დაახლოებითი დრო: %d წამი].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'შესრულების დრო ამოიწურა, დამუშავება უნდა გაგრძელდეს [დაახლოებითი დრო: %d წამი].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'მომხმარებელთა სიის მომზადების დრო დასაგზავნად შეზრუდულია. დარჩენილი მომხმარებლები არ არიან სიაში.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'ფოსტის გაგზავნის დრო შეზღუდულია. სხვა წერილები გამოტოვებულია.';
$lang['To send ?'] = 'გავგზავნოთ?';
$lang['Last send'] = 'ბოლო გაგზავნილები';
$lang['email'] = 'email';
$lang['User'] = 'მომხმარებელი';
$lang['Complementary mail content'] = 'წერილის ტექსტი';
$lang['See you soon,'] = 'ნახვამდის,';
$lang['Go to'] = 'გადავიდეთ ';
$lang['Hello'] = 'გამარჯობა ';
$lang['New photos were added'] = 'ახალი ელემენტები დამატებულია ';
$lang['on'] = ' ში ';
$lang['between'] = 'შორის ';
$lang['and'] = ' და ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'ადმინისტრატორმა მოგცათ უფლება მიიღოთ  შეტყობინები ფოსტის საშუალებით.';
$lang['You have subscribed to receiving notifications by mail.'] = 'თქვენ  დაადასტურეთ ხელმოწერა შეტყობინებების ფოსტით მიღებაზე.';
$lang['To subscribe'] = 'ხელმოწერა';
$lang['If you encounter problems or have any question, please send a message to'] = 'თუკი გაგიჩნდებათ რაიმე პრობლემა ან კითხვები, მოგვწერეთ ';
$lang['[NBM] Problems or questions'] = 'პრობლემები და შეკითხვები';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'ადმინისტრატორმა დაბლოკა უფლება მიიღოთ  შეტყობინები ფოსტის საშუალებით.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'თქვენ წაშალეთ ხელმოწერა შეტყობინებების ფოსტის მიღებაზე.';
$lang[', click on'] = ', დაწკაპეთ ';
$lang['To unsubscribe'] = 'რათა გააუქმოთ ხელმოწერა';
$lang['With blank value, gallery title will be used'] = 'თუკი არ არის შევსებული, გამოყენებული იქნება გალერეის სახელი';
$lang['Notification'] = 'შეტყობინებები';
$lang['Error when sending email to %s [%s].'] = 'ფოსტის გაგზავნის შეცდომა %s [%s] თვის.';
$lang['Mail sent to %s [%s].'] = 'წერილი გაგზავნილია %s [%s] თვის.';
$lang['%d mail was sent.'] = 'გაგზავნილია წერილი: %d.';
$lang['%d mails were sent.'] = 'გაგზავნილია წერილები: %d.';
$lang['%d mail was not sent.'] = 'გაუგზავნელი წერილი: %d.';
$lang['%d mails were not sent.'] = 'გაუგზავნელი წერილები: %d.';
$lang['No mail to send.'] = 'არ არის გასაგზავნი წერილები.';
$lang['There is no available subscribers to mail.'] = 'არ არიან მომხმარებლები, ვისთვისაც შეიძლება წერილის გაგზავნა.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'მომხმარებლები არსებობენ, თუკი არის ახალი შეტყობინების ელემენტები.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'შესაძლებელია ,არ არიან ხელმომწერები (მხოლოდ ადმინისტრატორი ხედავს ამას).';
$lang['No user to send notifications by mail.'] = 'არ არიან მომხმარებლები, რომ გაუგზავნოთ სეტყობინება ფოსტით..';
$lang['New photos added'] = 'დამატებულია ახალი ელემენტი';
$lang['Subscribe to notification by mail'] = 'ხელმოწერა ფოსტით შეტყობინებაზე';
$lang['Unsubscribe from notification by mail'] = 'ხელმოწერის გაუქმება ფოსტით შეტყობინებაზე';
$lang['Parameter'] = 'პარამეტრები';
$lang['Continue processing treatment'] = 'გავაგრძელოთ მიმართვის დამუშავება';
$lang['Complementary mail content'] = 'წერილის დამატებითი შემადგენლობა';
$lang['Add detailed content'] = 'დავამატოთ დამატებითი შემადგენლობა';
$lang['Send mail as'] = 'გავაგზავნოთ წერილი';
$lang['Send mail to users'] = 'გაუგზავნოთ წერილი მომხმარებელს';
$lang['Send'] = 'გაგზავნა';
$lang['Options'] = 'პარამეტრები';
$lang['Send'] = 'გაგზავნა';
$lang['Subscribed'] = 'დასაგზავნთა სიაში';
$lang['Subscribe'] = 'დაგზავნის სია';
$lang['Parameters'] = 'პარამეტრები';
$lang['Select recipients'] = 'ავირჩიოთ მიმღებები';
$lang['Subscribe/unsubscribe users'] = 'მონაწილეთა დამატება/წაშლა დაგზავნის სიაში';
$lang['Unsubscribed'] = 'არ არის დაგზავნის სიაში';
$lang['%d parameter was updated.'] = '%d პარამეტრი განახლებულია.';
$lang['%d parameters were updated.'] = '%d პარამეტრი განახლებულია.';
$lang['%d user was not updated.'] = '%d მომხმარებელი არ არის განახლებული.';
$lang['%d users were not updated.'] = '%d მომხმარებელი არ არის განახლებული.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Пользователь %s [%s] წაშლილია დაგზავნის სიიდან.';
$lang['User %s [%s] was added to the subscription list.'] = 'Пользователь %s [%s] დამატებულია დაგზავნის სიაში.';
$lang['%d user was updated.'] = '%d მომხმარებელი შეცვლილია.';
$lang['%d users were updated.'] = '%d მომხმარებელი შეცვლილია.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'მომხმარებელი %s [%s] არ არის წაშლილი დაგზავნის სიიდან.';
$lang['User %s [%s] was not added to the subscription list.'] = 'მომხმარებელი %s [%s] არ არის დამატებული დაგზავნის სიაში.';
$lang['User %s [%s] added.'] = 'მომხმარებელი %s [%s] დამატებულია.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'ყურადღება: დაგზავნის სიაში დამატება/წაშლისას მომხმარებლებს გეაგზავნებათ შეტყობინება';
$lang['Send mail on HTML format'] = 'გავაგზავნოთ წერილი HTML ფორმატში';
$lang['Include display of recent photos grouped by dates'] = 'ჩავრთოთ თარიღის მიხედვით დაწყობილი ბოლო ფოტოების გამოსახვა';
$lang['Available only with HTML format'] = 'შესაძლებელია მხოლოდ HTML ფორმატში';
$lang['no write access'] = 'ჩაწერაზე დაშვება არ არის';
$lang['Permissions'] = 'დაშვებები';
$lang['private'] = 'პრივატული';
$lang['Properties'] = 'Свойства';
$lang['public'] = 'საერთო';
$lang['Purge never used notification feeds'] = 'გავწმინდოთ გამოუყენებელი შეტყობინებების არხები';
$lang['Purge sessions'] = 'გავწმინდოთ სესიები';
$lang['randomly represented'] = 'შემთხვევითი წარმომადგენელი';
$lang['registration date'] = 'რეგისტრაციის თარიღი';
$lang['clean'] = 'გავწმინდოთ';
$lang['remove remote listing.xml file'] = 'წავშალოთ მოშორებული ფაილი listing.xml';
$lang['generate listing'] = 'შევქმნათ ლისტინგი';
$lang['generate file listing.xml on remote site'] = 'შევქმნათ ფაილი listing.xml სხვა დაშორებულ საიტზე';
$lang['Create this site'] = 'შევქმნათ ეს საიტი';
$lang['A local listing.xml file has been found for'] = 'ლოკალური ფაილი listing.xml file მოიძებნა ';
$lang['read local listing.xml and update'] = ' წავიკითხოთ ლოკალური ფაილი listing.xml და განვაახლოთ ';
$lang['test'] = 'ტესტი';
$lang['test this remote site'] = 'დავტესტოთ ეს დაშორებული საიტი';
$lang['remove tags'] = 'წავშალოთ სიტყვები';
$lang['Repair and optimize database'] = 'მონაცემთა ბაზის გასწორება და ოპტიმიზაცია';
$lang['selection'] = 'აღნიშნულები';
$lang['set to'] = 'შევცვალოთ';
$lang['singly represented'] = 'აღნიშნული წარმომადგენელი';
$lang['This site already exists'] = 'ასეთი საიტი უკვე არის';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'შევქმნათ ახალი საიტი: (ჩაწერეთ URL  create_listing_file.php -ში)';
$lang['created'] = 'შექმნილია';
$lang['delete'] = 'წაშლილია';
$lang['delete this site and all its attached elements'] = 'წავშალოთ ეს საიტი და ყველა მიმაგრებული ელემენტი';
$lang['an error happened'] = 'მოხდა შეცდომა';
$lang['file create_listing_file.php on remote site was not found'] = 'ფაილი create_listing_file.php არ მოიძებნა დაშორებულ საიტზე';
$lang['Local'] = 'ლოკალური';
$lang['Remote'] = 'დაშორებული';
$lang['synchronize'] = 'სინქრონიზაცია';
$lang['update the database from files'] = 'განვაახლოთ მონაცემების გბაზა ფაილებიდან';
$lang['status'] = 'სტატუსი';
$lang['Directory'] = 'ფოლდერი';
$lang['sub-albums'] = 'ქვეკატეგორიები';
$lang['synchronize metadata'] = 'მეტამონაცემების სინქრონიზაცია';
$lang['synchronize'] = 'სინქრონიზაცია';
$lang['target'] = 'შევცვალოთ';
$lang['Thumbnail'] = 'მინიატურა';
$lang['title'] = 'სათაური';
$lang['Album list management'] = 'კატეგორიების მართვა';
$lang['Piwigo configuration'] = ' PhpWebGallery მართვა';
$lang['Edit album'] = 'კატეგორიების რედაქტირება';
$lang['Group management'] = 'ჯგუფების მართვა';
$lang['User list'] = 'მომხმარებლების სია';
$lang['Edit photo information'] = 'შევცვალოთ ინფორმაცია ფოტოზე';
$lang['Thumbnail creation'] = 'მინიატურების შექმნა';
$lang['Database synchronization with files'] = 'მონაცემთა ბაზის სინქრონიზაცია ფაილებთან';
$lang['all'] = 'ყველა';
$lang['photos without thumbnail (jpeg and png only)'] = 'ფოტოები მინიატურების გარეშე (მხოლოდ jpeg და png)';
$lang['height must be a number superior to'] = 'სიმაღლე უნდა იყოს მეტი რიცხვი';
$lang['width must be a number superior to'] = 'სიგანე უნდა იყოს მეტი რიცხვი';
$lang['for the file format'] = 'ფაილის ფორმატისათვის';
$lang['No missing thumbnail'] = 'მინიატურები აქვს ყველა ფოტოს';
$lang['Photo unreachable or no support'] = 'ფოტო მიუწვდომელია ან არ არის მისი ფორმატის მხარდაჭერა';
$lang['GD version'] = 'ვერსია GD';
$lang['Miniaturization parameters'] = 'მინიატურიზაციის პარამეტრები';
$lang['generated in'] = 'გენერირებულია';
$lang['Results of miniaturization'] = 'მინიატურიზაციის რეზულტატი';
$lang['General statistics'] = 'საერთო სტატისტიკა';
$lang['max time'] = 'მაქსიმალური დრო';
$lang['average time'] = 'საშუალო დრო';
$lang['min time'] = 'მინიმალური დრო';
$lang['number of miniaturized photos'] = 'შემცირებული ფოტოების რაოდენობა';
$lang['total time'] = 'საერთო დრო';
$lang['for this file format'] = 'ამ ფაილის ფორმატისათვის';
$lang['unit mode'] = 'ერთეული რეჟიმი';
$lang['Unlocked'] = 'ბლოკის მოხსნა';
$lang['unset'] = 'გავასუფთაოთ';
$lang['Update albums informations'] = 'განვაახლოთ ინფორმაცია კატეგორიებზე';
$lang['Update photos information'] = 'განვაახლოთ ინფორმაცია ფოტოებზე';
$lang['Synchronize'] = 'სინქრონიზაცია';
$lang['reduce to single existing albums'] = 'შევამოწმოთ მხოლოდ კატეგორია';
$lang['Choose an option'] = 'აირჩიეთ პარამეტრები';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'ვნახოთ ინფორმაციის მაქსიმუმი (დამატებული კატეგორიები და ფოტოები, წაშლილი ფოტოები და ელემენტები)';
$lang['Piwigo version differs on the remote site'] = 'PhpWebGallery ვერსია განსხვავდება დაშორებულ სერვერზე';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'ვერსიები create_listing_file.php დაშორებულ სერვერზე და PhpWebGallery უნდა იყოს ერთი და იგივე';
$lang['listing.xml file was not found'] = 'ფაილი listing.xml არ მოიძებნა';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'ფაილი listing.xml არ მოიძებნა დაშორებულ საიტზე.ეს ფაილი იქმნება საიტების მართვის სისტემაში "შევქმნათ ლისტინგი" ბრძანების არჩევისას';
$lang['Error list'] = 'შეცდომების სია';
$lang['Errors caption'] = 'შეცდომების განმარტება';
$lang['Detailed informations'] = 'დეტალური ინფორმაცია';
$lang['File/directory read error'] = 'შეცდომია ფაილის/პაპკის კითხვისას';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'ფაილთან ან ფოლდერთან დაკავშირება არ მოხერხდა.(შესაძლებელია არ გაქვთ დაშვების უფლება ან მათთან დაშვება აკრძალულია)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'ფაილის ამ ტიპისათვის საჭიროა მინიატურა.მინიატურები უნდა განათავსოთ ქვეფოლდერში  "thumbnail" კატეგორიის ფოლდერში. მინიატურის ფაილის სახელი უნდა იწყებოდეს კონფიგურაციის დროს მითითებული პრეფიქსით,ხოლო მისი გაფართოება უნდა იყოს ერთ-ერთი ქვემოთ ჩამოთვლილთაგან:';
$lang['missing thumbnail'] = 'მინიატურები არ არის';
$lang['albums deleted in the database'] = 'კატეგორია წაშლილია მონაცემთა ბაზიდან';
$lang['photos deleted from the database'] = 'ელემენტი წაშლილია მონაცემთა ბაზიდან';
$lang['photos candidates for metadata synchronization'] = 'სურათი მეტამონაცემების სინქრონიზაციისათვის';
$lang['photos informations synchronized with files metadata'] = 'ინფორმაცია ელემენტებზე სინქრონირებულია ფაილების მეტამონაცემებთან';
$lang['errors during synchronization'] = 'სინქრონიზაციის შეცდომები';
$lang['albums added in the database'] = 'კატეგორიები დამატებულია მონაცემთა ბაზაში';
$lang['photos added in the database'] = 'ელემენტები დამატებულია მონაცემთა ბაზაში';
$lang['photos updated in the database'] = 'ელემანტები განახლებულია მონაცემთა ბაზაში';
$lang['Search for new images in the directories'] = 'ახალი ფოტოების ძებნა პაპკებში';
$lang['added'] = 'დამატებულია';
$lang['deleted'] = 'წაშლილია';
$lang['Metadata synchronization results'] = 'მეტამონაცემების სინქრონიზაციის შედეგები';
$lang['only perform a simulation (no change in database will be made)'] = 'მხოლოდ ტესტირება (არ შევიტანოთ ცვლილებები მონაცემთა ბაზაში)';
$lang['[Simulation]'] = '[ტესტი]';
$lang['Simulation'] = 'ტესტი';
$lang['directories + files'] = 'ფაილები და ფოლდერები';
$lang['only directories'] = 'მხოლოდ ფოლდერები';
$lang['synchronize files structure with database'] = 'ფაილების სტრუქტურის სინქრონიზაცია მონაცემთა ბაზასთან';
$lang['synchronize files metadata with database photos informations'] = 'ფაილების მეტამონაცემების სინქრონიზაცია მონაცემთა ბაზასთან';
$lang['even already synchronized photos'] = 'ყველა, ადრე სინქრონიზებულის ჩათვლით';
$lang['Used metadata'] = 'გამოYენებული მეტამონაცემები';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'ფაილების ან ფოლდერების სახელი უნდა შედგებოდეს ასოების,ციფრების "-", "_" და "." სგან';
$lang['wrong filename'] = 'ფაილის არასწორი სახელი';
$lang['Upload'] = 'Зატვირთვა';
$lang['user "%s" added'] = 'მომხმარებელი "%s" დამატებულია';
$lang['User status'] = 'მომხმარებლის სტატუსი';
$lang['user_status_admin'] = 'ადმინისტრატორი';
$lang['user_status_generic'] = 'საერთო';
$lang['user_status_guest'] = 'სტუმარი';
$lang['user_status_normal'] = 'მომხმარებელი';
$lang['user_status_webmaster'] = 'ვებდიზაინერი';
$lang['Users'] = 'მომხმარებლები';
$lang['Virtual album'] = 'ვირტუალური კატეგორია';
$lang['Waiting'] = 'მოცდის პროცესში';
$lang['default'] = 'ძირითადად';
$lang['Toggle \'default group\' property'] = 'შევქმათ/მოვაშოროთ  \'ძირითადად\'';
$lang['Advanced features'] = 'გაფართოებული ფუნქციები';
$lang['Specials'] = 'სპეც ფუნქციები';
$lang['Overall'] = 'ყველა';
$lang['Year'] = 'წელი';
$lang['Month'] = 'თვე';
$lang['Day'] = 'დღე';
$lang['Pages seen'] = 'გვერდია ნანახი';
$lang['Time'] = 'დრო';
$lang['User'] = 'მომხმარებელი';
$lang['IP'] = 'IP';
$lang['Element'] = '';
$lang['Section'] = 'განყოფილება';
$lang['Tags'] = 'სიტყვები';
$lang['Save page visits by guests'] = 'შევინახოთ სტუმრების მიერ ნანახი გვერდები';
$lang['Save page visits by users'] = 'შევინახოთ მომხმარებლის მიერ ნანახი გვერდები';
$lang['Save page visits by administrators'] = 'შევინახოთ ადმინისტრატორის მიერ ნანახი გვერდები';
$lang['Properties'] = 'თვისება';
$lang['An information email was sent to group "%s"'] = 'საინფორმაციო წერილი გაგზავნილია "%s" ჯგუფისთვის';
$lang['Send an information email to group members'] = 'გავაგზავნოთ საინფორმაციო წერილი ჯგუფისთვის';
$lang['Group'] = 'ჯგუფი';
$lang['[%s] Visit album %s'] = '[%s] გიწვევთ %s კატეგორიაში';
$lang['Hello,'] = 'გამარჯობა,';
$lang['See you soon.'] = 'ნახვამდისД.';
$lang['Discover album:'] = 'მობრძანდით კატეგორიში:';
$lang['Mail content'] = 'შინაარსი';
$lang['none'] = 'არა';
$lang['high'] = 'დიდი';
$lang['other'] = 'სხვა';
$lang['Element type'] = 'ელემენტის ტიპი';
$lang['User'] = 'მომხმარებელი';
$lang['Image id'] = 'ფოტოს id';
$lang['Summary'] = 'სუმარულად';
$lang['%d line filtered'] = '%d ხაზი გაფილტრულია';
$lang['%d lines filtered'] = '%d ხაზი გაფილტრულია';
$lang['%d guest'] = '%d სტუმარი';
$lang['%d guests'] = '%d სტუმრები';
$lang['Hour'] = 'საათი';
$lang['guest'] = 'სტუმარი';
$lang['default values'] = 'ძირითAდი მნიშვნელობა';
$lang['High filesize'] = 'ფაილის დიდი ზომა';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'შტუმრის წაშლა არ შეიძლება';
$lang['Default user cannot be deleted'] = 'ძირითადი მომხმარებელის წაშლა არ შეიძლება';
$lang['Purge history detail'] = 'გავასუფთაოთ ისტორია';
$lang['Purge history summary'] = 'გავასუფთაოთ მთელი ისტორია';
$lang['Check integrity'] = 'შესაბამისობის შემოწმება';
$lang['Anomaly'] = 'გაუმართაობა';
$lang['Correction'] = 'კორექტირება';
$lang['Automatic correction'] = 'ავტომატური კორექტირება';
$lang['Impossible automatic correction'] = 'ავტომატური კორექტირება შეუძლებელია';
$lang['Correction applied with success'] = 'კორექტირებამ წარმატებით ჩაიარა';
$lang['Correction applied with error'] = 'კორექციამ შეცდომებით ჩაიარა';
$lang['%d anomaly has been detected.'] = 'აღმოჩენილია %d გაუმართაობა.';
$lang['%d anomalies have been detected.'] = 'აღმოჩენილია %d გაუმართაობები.';
$lang['%d anomaly has been corrected.'] = 'კორექტირებულია %d გაუმართაობა.';
$lang['%d anomalies have been detected corrected.'] = 'კორექტირებულია %d გაუმართაობები.';
$lang['%d anomaly has not been corrected.'] = 'არ არის კორექტირებული %d გაუმართაობა.';
$lang['%d anomalies have not been corrected.'] = 'არ არის კორექტირებული %d გაუმართაობები.';
$lang['Go to %s or %s for more informations'] = 'ნახეთ %s ან %s დამატებითი ინფორმაციის მისაღებად';
$lang['the forum'] = 'ფორუმი';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = 'მნიშვნელობა %s ფაილში არა სწორია,რადგან exif მხარდაჭერა არაა';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s საჭიროა გათიშოთ ფაილში config_local.inc.php';
$lang['Main "guest" user does not exist'] = 'მომხმარებლის სტატუსი "სტუმარი" აღარ არსებობს';
$lang['Main "guest" user status is incorrect'] = 'მომხმარებლის სტატუსი "სტუმარი" არა კორექტულია';
$lang['Default user does not exist'] = 'ძირითადი მომხმარებელი აღარ არსებობს';
$lang['Main "webmaster" user does not exist'] = 'მომხმარებელი "ვებდიზაინერი" აღარ არსებობს';
$lang['Main "webmaster" user status is incorrect'] = 'მომხმარებლის სახელი "ვებდიზაინერი" არა კორექტულია';
$lang['User "%s" created with "%s" like password'] = 'მომხმარებელი "%s" შექმნილია პაროლით "%s"';
$lang['Status of user "%s" updated'] = 'მომხმარებელი "%s" სტატუსი განახლებულია';
$lang['add new photos to caddie'] = 'დავამატოთ ახალი ფოტოები კალათაში';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = 'არ ვანახოთ';
$lang['Classic display'] = 'კლასიკური სახე';
$lang['Hoverbox display'] = 'სახე Hoverbox';
$lang['Mail address is obligatory for all users'] = 'ელ. ფოსტის მისამართი აუცილებელია ყველა მომხმარებლისათვის';
$lang['Minimum privacy level'] = 'დაცვის მინიმალური დონე';
$lang['Privacy level'] = 'დაცვის დონე';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'კონტაქტი';
$lang['Level 2'] = 'მეგობრები';
$lang['Level 4'] = 'ოჯახი';
$lang['Level 8'] = 'ადმინისტრაცია';
$lang['Reinitialize check integrity'] = 'გავიმეოროთ მთლიანობის შემოწმება';
$lang['Check all'] = 'ავღნიშნოთ ყველა';
$lang['Uncheck all'] = 'მოვხსნათ ყველა აღნიშვნა';
$lang['Check automatic corrections'] = 'აღვნიშნოთ ავტოკორექცია';
$lang['Apply selected corrections'] = 'გამოვიყენოთ აღნიშნული კორექციები';
$lang['Ignore selected anomalies'] = 'აღნიშნული გაუმართაობების იგნორირება';
$lang['Refresh'] = 'განვაახლოთ';
$lang['The anomaly will be ignored until next application version'] = 'გაუმართაობები იგნორირებული იქნება სკრიპტის შემდგომი ვერსიის დაყენებამდე';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'გაუმართაობის კორექტირება გათიშავს მათ იგნორირებას';
$lang['%d anomaly has been ignored.'] = '%d გაუმართაობა იგნორირებულია.';
$lang['%d anomalies have been ignored.'] = 'იგნორირებული იქნა გაუმართაობები: %d';
$lang['Plugins which need upgrade'] = 'პლაგინები, რომლებიც ითხხოვენ განახლებას';
$lang['Plugin list'] = 'პლაგინების სია';
$lang['Check for updates'] = 'განახლების შემოწმება';
$lang['Other plugins'] = 'სხვა პლაგინები';
$lang['Last revisions'] = 'ბოლო ცვლილებები';
$lang['Delete'] = 'წავშალოთ';
$lang['Are you sure you want to delete this plugin?'] = 'დარწმუნებული ხართ, რომ გინდათ წაშალოთ ეს პლაგინი?';
$lang['Are you sure you want to install this plugin?'] = 'დარწმუნებული ხართ, რომ გინდათ დააყენოთ ეს პლაგინი?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'დარწმუნებული ხართ, რომ გინდათ განაახლოთ? შეამოწმეთ, ხომ არ ჭირდება ამ ვერსიას დეინსტალაცია.';
$lang['%s has been successfully upgraded.'] = '%s წარმატებით განახლდა.';
$lang['Plugin has been successfully copied'] = 'პლაგინი წარმატებით იქნა კოპირებული';
$lang['You might go to plugin list to install and activate it.'] = 'შეგიძლიათ გადახვიდეთ პლაგინების სიასთან მის დასაყენებლად და აქტივაციისათვის.';
$lang['Can\'t create temporary file.'] = 'შეუძლებელია დროებითი ფაილის შექმნა.';
$lang['Can\'t download archive.'] = 'შეუძლებელია არქივის ჩამოტვირთვა.';
$lang['Can\'t read or extract archive.'] = 'შეუძლებელია არქივის წაკითხვა.';
$lang['An error occured during extraction (%s).'] = 'შეცდომაა გახსნის პროცესშიО (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'გთხოვთ, შეამოწმოთ ფოლდერ "plugins"-ის და მისი ქვეფოლდერების უფლებები (CHMOD).';
$lang['Can\'t connect to server.'] = 'სერვერთან დაკავშირება შეუძლებელია.';
$lang['Purge compiled templates'] = 'გავასუფთაოთ შექმნილი შაბლონები';
$lang['Upload'] = 'ატვირთვები';
$lang['ACCESS_0'] = 'თავისუფალი დაშვება';
$lang['ACCESS_1'] = 'დაშვებულია ყველასთვის';
$lang['ACCESS_2'] = 'დაშვებულია რჩეულებისათვის';
$lang['ACCESS_3'] = 'დაშვებულია ადმინისტრატორებისთვის';
$lang['ACCESS_4'] = 'დაშვებულია ვებდიზაინერისათვის';
$lang['ACCESS_5'] = 'დაუშვებელია';
$lang['Support'] = 'მხარდაჭერა';
$lang['Documentation'] = 'დოკუმენტაცია';
$lang['A new version of Piwigo is available.'] = 'ხელმისაწვდომია Piwigo-ს ახალი ვერსია.';
$lang['Piwigo Administration'] = 'Piwigo-ს ადმინისტრაცია';
$lang['Piwigo version'] = 'Piwigo-ს ვერსია';
$lang['You are running the latest version of Piwigo.'] = 'გაშვებულია Piwigo-ს ბოლო ვერსია.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'დაყენებული ვერსია %s [%s] შეუსაბამოა [%s] ვერსიასთან';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'რათა გამოიყენოთ სკრიპტის მტელი შესაძლებლობები, განაახლეთ სისტემა, წინააღმდეგ შემთხვევაში სკრიპტმა შესაძლოა შეცდომებით იმუშაოს';
$lang['Deleted on'] = 'წაშლილია';
$lang['Last hit'] =  'ბოლო ნაჩვენები';
$lang['GD library is missing'] = 'GD ბიბლიოთეკა არ არსებობს';
$lang['Templates'] = 'შაბლონები';
$lang['Extend for templates'] = 'გაფართოებები შაბლონებისათვის';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] =
 'შევცვალოთ ორიგინალი შაბლონები მომხმარებლის შაბლონებით ქვეფოლდერიდანtemplate-extension';
$lang['Replacers (customized templates)'] = 'შემცვლელი (მომხმარებლის შაბლონი)';
$lang['Original templates'] = 'ორიგინალი შაბლონი';
$lang['Optional URL keyword'] = 'ოპციონალური URL საკვანძო სიტყვა';
$lang['Templates configuration has been recorded.'] = 'თარგების კონფიგურაცია ჩაწერილია.';
$lang['All optimizations have been successfully completed.'] = 'ყველა ოპტიმიზაციამ წარმატებით ჩაიარა.';
$lang['Optimizations have been completed with some errors.'] = 'ოპტიმიზაცია დასრულდა შეცდომებით.';
$lang['Modify information'] = 'Modify information';
$lang['edit album'] = 'კატეგორიის რედაქტირება';
$lang['nothing'] = 'არაფერი';
$lang['overrides existing values with empty ones'] = 'შევცვალოთ არსებული მნიშვნელობები ცარიელით';
$lang['manage photo ranks'] = 'ფოტოების მართვის წესი';
$lang['Manage photo ranks'] = 'ფოტოების მართვის წესი';
$lang['Edit ranks'] = 'შევცვალოთ წესი';
$lang['No photo in this album'] = 'ცარიელი კატეგორია';
$lang['Images manual order was saved'] = 'ფოტოებისთვის აღნიშნული წესი შენახულია';
$lang['ranks'] = 'წესი';
$lang['Drag to re-order'] = 'გადმოიტანეთ რათა შეცვალოთ წესი';
$lang['Quick Local Synchronization'] = 'ჩქარი სინქრონიზაცია';
$lang['No photo can be deleted'] = 'არ არის ფოტო წასაშლელად';
$lang['Delete selected photos'] = 'წავშალოთ არჩეული ფოტოები';
$lang['%d photo was deleted'] = '%d ფოტო წაშლილია';
$lang['%d photos were deleted'] = '%d ფოტო წაშლილია';
$lang['Unable to check for upgrade.'] = 'შეუძლებელია განახლების შემოწმება.';
$lang['Date'] = 'თარიღი';
$lang['Operation in progress'] = 'მიმართვის დამუშავება.';
$lang['Please wait...'] = 'გთხოვთ მოიცადოთ...';
$lang['Downloads'] = 'ჩამოტვირთვები';
$lang['Released on'] = 'გამოშვება';
$lang['Number of downloads'] = 'ჩამოტვირთვების რაოდენობა';
$lang['Piwigo Announcements Newsletter'] = 'Piwigo საინფორმაციო დაგზავნა';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'იყავით კავშირზე პროექტ Piwigo სთან ერთად, თქვენ მიიღებთ შეტყობინებას როგორც კი გამოვა ახალი გამოცემა (ზოგჯერ წერილი შეიცავს შეცდომების გამოსწორებას, უსაფრთხოების ზომების შესახებ და თქვენ უნდა იცოდეთ ეს), ან როცა იქნება რამე მნიშვნელოვანი მოვლენა ან პროექტი. ეს მხოლოდ რამდენიმე წერილია წელიწადში.';
$lang['Subscribe %s'] = 'ხელმოწერა %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'ხელმოწერა %s Piwigo საინფორმაციო დაგზავნაზე';
$lang['Purge search history'] = 'გავასუფთაოთ ძებნის ისტორია';
$lang['Hide'] = 'დავფაროთ';
$lang['Password is missing. Please enter the password.'] = 'პაროლი არა სწორია. გთხოვთ გაიმეოროთ.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'პაროლის დადასტურება არ არის. გთხოვთ დაადასტურეთ არჩეული პაროლი.';
$lang['Password confirmation error.'] = 'შეცდომა პაროლის დადასტურებისას.';
$lang['Allow users to edit their own comments'] = 'ნება დავრთოთ მომხმარებლებს თავიანთი კომენტარის რედაქტირებაზე';
$lang['Allow users to delete their own comments'] = 'ნება დავრთოთ მომხმარებელს წაშალოს თავისი კომენტარი';
$lang['Email administrators when a comment is modified'] = 'შევატყობინოთ ადმინისტრატორს ელ.ფოსტით, როცა კომენტარი შეიცვლება';
$lang['Email administrators when a comment is deleted'] = 'შევატყობინოთ ადმინისტრატორს ელ.ფოსტით, როცა კომენტარი წაიშლება';
$lang['Cannot delete the old permalink !'] = 'ძველი მუდმივი ბმული არ შეიძლება წაიშალოს!';
$lang['Hit'] = 'პოპულარული';
$lang['Tools'] = 'ინსტრუმენტები';
$lang['Photos'] = 'ფოტოები';
$lang['Themes'] = 'თემები';
$lang['Instructions to use Piwigo'] = 'Piwigo მოხმარების ინსტრუქცია';
$lang['Installed Themes'] = 'დაყენებული თემები';
$lang['Add New Theme'] = 'დავამატოთ ახალი თემა';
$lang['Forbid this theme to users'] = 'აუკრზალოთ მომხმარებელს ამ თემის გამოყენება';
$lang['Set as default theme for unregistered and new users'] = 'დავაყენოთ ეს თემა ახალი და დაურეგისტრირებელი მომხმარებელისათვის ძირითადად';
$lang['unknown'] = 'უცნობია';
$lang['Upload Photos'] = 'ავტვირთოთ ფოტოები';
$lang['Drop into album'] = 'ავტვირთოთ კატეგორიაში';
$lang['+ Add an upload box'] = '+ დავამატოთ ასატვირთი ველი';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'შექმენით "%s" კატალოგი თქვენს მიერ დაყენებული Piwigo-ს ფუძეში';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'მიეცით ჩაწერაზე დაშვება (chmod 777)  "%s" კატალოგს, თქვენს მიერ დაყენებული Piwigo-ს ფუძეში';
$lang['existing album'] = 'არსებული კატეგორია';
$lang['create a new album'] = 'შევქმნათ ახალი კატეგორია';
$lang['Album name'] = 'კატეგორიის სახელი';
$lang['Album "%s" has been added'] = 'კატეგორია "%s" დამატებულია';
$lang['Uploaded Photos'] = 'ატვირთული ფოტოები';
$lang['%d photos uploaded'] = '%d ფოტოები ატვირთულია';
$lang['Privacy level set to "%s"'] = 'დავაყენოთ დაშვების უფლება "%s"';
$lang['Album "%s" now contains %d photos'] = 'კატეგორია "%s" შეიცავს ამჟამად %d ფოტოს';
$lang['Manage this set of %d photos'] = 'ამ კრებულის რედაქტირება, შემცველობით %d Fოტო';
$lang['Select files'] = 'ავირჩიოთ ფაილები';
$lang['Everybody'] = 'ყველა';
$lang['Who can see these photos?'] = 'ვის შეუძლია ნახოს ეს ფოტოები?';
$lang['The websize maximum width must be a number between %d and %d'] = 'ფოტოს მაქსიმალური სიგანე უნდა იყოს რიცხვი %d და %d შორის';
$lang['The websize maximum height must be a number between %d and %d'] = 'ფოტოს მაქსიმალური სიმაღლე უნდა იყოს რიცხვი %d და %d შორის';
$lang['The websize image quality must be a number between %d and %d'] = 'ფოტოს ხარისხი უნდა იყოს რიცხვით %d და %d შორის';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'მინიატურის მაქსიმალური სიგანე უნდა იყოს რიცხვი  %d და %d შორის';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'მინიატურის მაქსიმალური სიმაღლე უნდა იყოს რიცხვი %d და %d შორის';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'მინიატურის ხარისხი უნდა იყოს რიცხვი %d და %d შორის';
$lang['Settings'] = 'პარამეტრები';
$lang['Web size photo'] = 'ფოტოს ზომა ინტერნეტისათვის';
$lang['Resize'] = 'ზომების შეცვლა';
$lang['Maximum Width'] = 'მაქსიმალური სიგანე';
$lang['pixels'] = 'პიქსელი';
$lang['Maximum Height'] = 'მაქსიმალური სიმაღლე';
$lang['Image Quality'] = 'ფოტოს ხარისხი';
$lang['Save Settings'] = 'შევინახოთ პარამეტრები';
$lang['Your configuration settings are saved'] = 'თქვენი კონფიგურაცია შენახულია';
$lang['Active Themes'] = 'აქტიური თემები';
$lang['Add write access to the "%s" directory'] = 'დაამატეთ ჩაწერის უფლება "%s" დირექტორიისათვის';
$lang['Administration Home'] = 'ადმინისტრირება';
$lang['Change Admin Colors'] = 'შევცვალოთ ადმინისტრირების პანელის ფერები';
$lang['Delete this theme'] = 'წავშალოთ ეს თემა';
$lang['Directory does not exist'] = 'დირექტორია არ არსებობს';
$lang['Download,'] = 'ჩამოვტვირთოთ,';
$lang['FTP + Synchronization'] = 'FTP + სინქრონიზაცია';
$lang['Get Support on Piwigo Forum'] = 'მიმართეთ დახმარებისათვის Piwigo-ს ფორუმს';
$lang['Help Me'] = 'დამეხმარეთ';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'ამ თემის აქტივაცია არ შეიძლება, რადგან მშობლიური თემა %s არ არსებობს';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'ამ თემის წაშლა არ შეიზლება, რადგან სხვა თემები %s დამოკიდებულნი არიან მასზე';
$lang['Inactive Themes'] = 'არა აქტიური თემები';
$lang['Install on your computer,'] = 'დააყენეთ თქვენს კომპიუტერზე,';
$lang['Make this theme available to users'] = 'გავხადოთ ეს თემა მომხმარებლებისთვის ხელმისაწვდომი';
$lang['Page end'] = 'გვერდის დასასრული';
$lang['Piwigo Uploader'] = 'Piwigo ამტვირთავი';
$lang['Read Piwigo Documentation'] = 'წაიკითხეთ Piwigo დოკუმენტაცია';
$lang['Start pLoader and add your photos.'] = 'გახსენით pLoader და დაამატეთ თქვენი ფოტოები.';
$lang['Switch to clear or dark colors for administration'] = 'ღია და მუქი ტონების არჩევა ადმინისტრირების პანელისათვის';
$lang['Theme has been successfully installed'] = 'თემა წარმატებით არის დაყენებული';
$lang['Visit Gallery'] = 'ნახეთ გალერეა';
$lang['Visit Piwigo project website'] = 'ნახეთ პროექტ Piwigo-ს საიტი ';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader ცვლის <em>Piwigo ამტვირთავს</em>. pLoader-ის მეშვეობით თქვენ შეგიძლიათ ლოკალურად მოამზადოთ ფოტოები და და ატვირთოთ თქვენს Piwigo ფოტო გალერეაში.';
$lang['Guest Settings'] = 'სტუმრის პარამეტრები';
$lang['Main Page'] = 'მთავარი გვერდი';
$lang['Photo Page'] = 'ფოტოების გვერდი';
$lang['Activate Navigation Bar'] = 'სანავიგაციო პანელის აქტივაცია';
$lang['Activate Navigation Thumbnails'] = 'მინიატურებში ნავიგაციის აქტივაცია';
$lang['Activate icon "%s"'] = 'გავააქტიუროთ ხატულა "%s"';
$lang['Activate field "%s"'] = 'გავააქტიუროთ ველი "%s"';
$lang['Photo Properties'] = 'ფოტოს თვისება';
$lang['Allow user customization'] = 'ნება დავრთოთ მომხმარებლებს შეცვალონ გალერეის სახე';
$lang['Languages'] = 'ენები';
$lang['Installed Languages'] = 'დაყენებული ენები';
$lang['Add New Language'] = 'დავამატოთ ახალი ენა';
$lang['Language has been successfully installed'] = 'ენა წარმატებით დაყენდა';
$lang['Select:'] = 'ავირჩიოთ:';
$lang['None'] = 'არც ერთი';
$lang['Invert'] = 'გადავწიოთ';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'შეუძლებელია ამ თემის დეაქტივაცია, თქვენ ერთი თემა მაინც უნდა გქონდეთ.';
$lang['Webmaster status is required.'] = 'საჭიროა ადმინისტრატორის სტატუსი.';
$lang['Bound Theme'] = 'დაკავშირებული თემა';
$lang['Allow rating'] = 'ნება დავრთოთ შეაფასონ';
$lang['Select at least one comment'] = 'აირჩიეთ ერთი კომენტარი მაინც';
$lang['Active Plugins'] = 'გავააქტიუროოთ პლაგინი';
$lang['Inactive Plugins'] = 'პლაგინის დეაქტივაცია';
$lang['Missing Plugins'] = 'დაკარგული პლაგინები';
$lang['Uninstalled Plugins'] = 'წაშლილი პლაგინები';
$lang['By %s'] = ' %s';
$lang['Visit plugin site'] = 'ვეწვიოთ პლაგინის საიტს';
$lang['Active Languages'] = 'გავააქტიუროთ ენები';
$lang['Delete this language'] = 'წავსალოთ ეს ენა';
$lang['Forbid this language to users'] = 'გავხადოთ ეს ენა მომხმარებლისათვის ხელმიუწვდომელი';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'შეუყძლებელია ამ ენის დეაქტივაცია, დააყენეთ ძირითად ენად სხვა მანამდე.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'შეუძლებელია ამ ენის დეაქტივაცია, თქვენ ერთი ენა მაინც უნდა გქონდეთ.';
$lang['Inactive Languages'] = 'ენის დეაქტივაცია';
$lang['Make this language available to users'] = 'გავხადოთ ეს ენა მომხმარებლებისათვის ხელმისაწვდომი';
$lang['Set as default language for unregistered and new users'] = 'დავაყენოთ ეს ენა დაურეგისტრირებელი მომხმარებლებისათვის ძირითადად';
$lang['Add Photos'] = 'ფოტოს დამატება';
$lang['Download'] = 'ჩამოვტვირთოთ';
$lang['The following tag was deleted'] = 'შემდეგი ნიშნულები წაშლილია';
$lang['Miscellaneous'] = 'სხვა და სხვა';
$lang['Virtual Links'] = 'ვირტ.ბმულები';
$lang['Templates configuration has been recorded.'] = 'შაბლონის კონფიგურაცის გადაწერილია.';
$lang['Modify information'] = 'ინფორმაცია ცვლილებების შესახებ';
$lang['There is no other language available.'] = 'არ არის სხვა ენები.';
$lang['There is no other plugin available.'] = 'არ არის სხვა პლაგინები.';
$lang['There is no other theme available.'] = 'არ არის სხვა თემები.';
$lang['By rank'] = 'რეიტინგით';
$lang['Manual order'] = 'დავალაგოთ ხელით';
$lang['Add another set of photos'] = 'დავამატოთ ფოტოები';
$lang['Order of menubar items has been updated successfully.'] = 'მენიუში განლაგების წესი წარმატებით შეიცვალა.';
$lang['This theme was not designed to be directly activated'] = 'ამ თემაში არ არის გათვლილი პირდაპირი აქტივაცია';
$lang['Who can see this photo?'] = 'ვის შეუძლია ამ ფოტოს ნახვა?';
$lang['Pending Comments'] = 'კომენტარის მოლოდინში';
$lang['Menu Management'] = 'მენიუ';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'თქვენს php.ini ფაილში, upload_max_filesize (%sB) მეტია ვიდრე post_max_size (%sB), თქვენ უნდა შეცვალოთ ეს პარამეტრი ';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif გაფართოება არ არის ხელმისაწვდომი, ადმინისტრატორმა უნდა გამორთოს exif–ის გამოყენება';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'ასატვირთი ფაილის ზომა აღემატება upload_max_filesize დირექტივას ფაილში php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'ატვირთული ფაილების ზომა აღემატება post_max_size დირექტივას ფაილში php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'ასატვირთი ფაილის ზომა აღემატება MAX_FILE_SIZE დირექტივას მითითებულს HTML ფორმაში';
$lang['The uploaded file was only partially uploaded'] = 'ასატვირთი ფაილი მოლოდ ნაწილობრივ აიტვირთა';
$lang['No file was uploaded'] = 'ფაილი არ არის ატვირთული';
$lang['Missing a temporary folder'] = 'არ არსებობს დროებითი ფოლდერი';
$lang['Failed to write file to disk'] = 'ფაილის დისკზე ჩაწერა არ მოხერხდა';
$lang['File upload stopped by extension'] = 'ფაილის ატვირთვა შეჩერებულია გაფართოების გამო';
$lang['Unknown upload error'] = 'უცნობი ატვირთვის შეცდომა';
$lang['Error on file "%s" : %s'] = 'შეცდომაა ფაილში "%s" : %s';
$lang['automatic order'] = 'ავტომატურად განლაგება';
$lang['manual order'] = 'ხელით განლაგება';
$lang['Albums automatically sorted'] = 'ალბომები ავტომატურად დალაგებულია';
$lang['Keep high definition'] = 'შევინახოთ მაღალი გარჩევადობით';
$lang['The high definition maximum width must be a number between %d and %d'] = 'მაღალი გარჩევადობისას მაქსიმალური სიგანე უნდა იყოს რიცხვი %d და %d შორის';
$lang['The high definition maximum height must be a number between %d and %d'] = 'მაღალი გარჩევადობისას მაქსიმალური სიმაღლე უნდა იყოს რიცხვი %d და %d შორის';
$lang['The high definition image quality must be a number between %d and %d'] = 'მაღალი გარჩევადობისას სურათის ხარისხი უნდა იყოს რიცხვი %d და %d შორის';
$lang['Batch Manager'] = 'სურათების მენეჯერი';
$lang['include child albums'] = 'მოიცავს ბავშვის ალბომებს';
$lang['Selection'] = 'არჩევა';
$lang['Action'] = 'მოქმედება';
$lang['Set author'] = 'ავტორი';
$lang['Set title'] = 'სათაური';
$lang['Set creation date'] = 'შექმნის თარიღი';
$lang['Apply action'] = 'არჩევანის დადასტურება';
$lang['on the %d selected photos'] = '%d მონიშნული ფოტო';
$lang['%d of %d photos selected'] = '%d დან %d ფოტოა შერჩეული';
$lang['No photo selected, %d photos in current set'] = 'ფოტო არ არის არჩეული, %d ფოტოა მიმდინარე კრებულში';
$lang['All %d photos are selected'] = 'ყველა %d ფოტოა არჩეული';
$lang['remove this filter'] = 'გამოვრთოთ ეს ფილტრი';
$lang['predefined filter'] = 'წინასწარგანსაზღვრული ფილტრი';
$lang['last import'] = 'ბოლო იმპორტი';
$lang['with no virtual album'] = 'არა ვირტუალური ალბომი';
$lang['duplicates'] = 'დუბლიკატები';
$lang['Add a filter'] = 'დავამატოთ ფილტრი';
$lang['Remove all filters'] = 'გავაუქმოთ ყველა ფილტრი';
$lang['Refresh photo set'] = 'განვაახლოთ ფოტოები';
$lang['The whole page'] = 'მთელი გვერდი';
$lang['The whole set'] = 'მთელი რიგი';
$lang['No photo in the current set.'] = 'არ არის სურათი მიმდინარე ნაკრებში.';
$lang['No photo selected, no action possible.'] = 'არ არის არჩეული არც ერთი ფოტო, მოქმედება შეუძლებელია.';
$lang['Choose an action'] = 'აირჩიეთ მოქმედება';
$lang['remove author'] = 'წავშალოთ ავტორი';
$lang['Type here the author name'] = 'ჩაწერეთ აქ ავტორის სახელი';
$lang['remove title'] = 'წავშალოთ სათური';
$lang['Type here the title'] = 'ჩაწერეთ აქ სათაური';
$lang['remove creation date'] = 'წავშალოთ შექმნის თარიღი';
$lang['with no album'] = 'ალბომის გარეშე';
$lang['with no tag'] = 'ტეგის გარეშე';
$lang['Album photos associated to the following albums: %s'] = 'ალბომის ფოტო ასოცირებულია შემდეგ ალბომთან: %s';
$lang['Delete orphan tags'] = 'დაობლებული ტეგების წაშლა';
$lang['delete photo'] = 'ფოტოს წაშლა';
$lang['Orphan tags deleted'] = 'დაობლებული ტეგები წაშლილია';
$lang['Remove from caddie'] = 'Remove from caddie';
$lang['Week starts on'] = 'კვირა იწყება';
$lang['You have %d orphan tags: %s.'] = 'თქვენ გაქვთ %d დაობლებული ტეგი: %s.';
$lang['Themes which need upgrade'] = 'თემები, რომელთაც სჭირდებათ განახლება';
$lang['Languages which need upgrade'] = 'ენები, რომელთაც სჭირდება განახლება';
$lang['All themes are up to date.'] = 'ყველა თემა განახლებულია.';
$lang['All plugins are up to date.'] = 'ყველა პლაგინი განახლებულია.';
$lang['All languages are up to date.'] = 'ყველა ენა განახლებულია.';
$lang['Visit theme site'] = 'ეწვიეთ თემის ვებ გვერდს';
$lang['Visit language site'] = 'ეწვიეთ ენის ვებ გვერდს';
$lang['New Version'] = 'ახალი ვერსია';
$lang['Obsolete Plugins'] = 'მოძველებული პლაგინები';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'გართხილება! ამ პლაგინს არ აქვს Piwigo–ს ამ ვერსიის მხარაჭერა.';
$lang['Do you want to activate anyway?'] = 'თქვენ მაინც გინდათ გაააქტიუროთ?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'ეს პლაგინი უკვე PIWIGO–ს ბირთვის ნაწილია! წაშალეთ იგი!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'შეცდომაა: ეს პლაგინი აკლია, მაგრამ იგი დაყენებულია! წაშალეთ იგი.';
$lang['display'] = 'ნახვა';
$lang['new'] = 'ახალი';
$lang['No results'] = 'შედეგი არ არის';
$lang['Searching...'] = 'ძიება...';
$lang['Type in a search term'] = 'ჩაწერეთ მოსაძებნი სიტყვა';
$lang['Learn more'] = 'გავიგოთ მეტი';
$lang['Rate'] = 'შეფასება';
$lang['Average rate'] = 'საშუალო ქულა';
$lang['An error has occured during upgrade.'] = 'განახლების დროს მოხდა შეცდომა.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'ამოარქივების დროს მოხდა შეცდომა. გთხოვთ, შეამოწმეთ დაშვების უფლება piwigo–ს ფოლდერთან.<br><a href="%s">დაკლიკეთ, რათა ნახოთ ინფორმაცია შეცდომაზე</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ვერ იღებს განახლების ფაილებს სერვერიდან';
$lang['Save Template Directory'] = 'შევინახოთ დირექტორიის შაბლონი';
$lang['Dump Database'] = 'მონაცემთა ბაზის წაშლა';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'ჩავრთოთ ისტორიის მონაცემები (გაფრთხილება: შესაძლებელია სერვერზე მეხსიერების ლიმიტის  გადაჭარბება)';
$lang['Unable to write new local directory.'] = 'შეუძლებელია ახალი ლოკალური დირექტორიის ჩაწერა.';
$lang['Unable to send template directory.'] = 'შეუძლებელია შაბლონის დირექტორიის გაგზავნა.';
$lang['Unable to dump database.'] = 'შეუძლებელია მონაცემთა ბაზის წაშლა.';
$lang['Update in progress... Please wait.'] = 'მიმდინარეობს განახლების პროცესი... გთხოვთ დაიცადოთ.';
$lang['Update to Piwigo %s'] = 'განაახლეთ Piwigo %s';
$lang['Two updates are available'] = 'ორი განახლებაა ხელმისაწვდომი';
$lang['This is a minor update, with only bug corrections.'] = 'ეს მცირე განახლებაა, მხოლოდ შეცდომების შესწორება.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'ეს ძალიან დიდი განახლებაა <a href="%s">საინტერესო სიახლეებით</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'თემების და პლაგინების ნაწილი ჯერჯერობით არ არის ხელმისაწვდომი.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'თქვენ პირდაპირ შეგიძლიათ  Piwigo %s გადახვიდეთ,  Piwigo %s განახლების გარეშე(რეკომენდირებულია).';



?>